==> ajsonapi-0.8.1-py3-none-any.whl: ajsonapi/attribute.py <==
# Copyright © 2018-2020 Roel van der Goot
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
"""Module attribute provides class Attribute."""

from ajsonapi.field import Field


class Attribute(Field):
    """Attributes are used to specify data members of object model classes
    (classes derived from JSON_API).
    """

    def __init__(self, type_, *, nullable=False, default=None):
        self.type_ = type_
        self.name = ''  # Overridden in JSON_API.__init_subclass__
        self.nullable = nullable
        self.default = default

    def filter_values(self, values):
        sql_values = [self.type_.sql(value) for value in values]
        return ','.join(sql_values)

    def filter_condition(self, values):
        return values

    def sql(self):
        """Creates the SQL column definition for this attribute.

        Returns:
            A string containing the SQL column definition for this attribute.
        """

        if self.nullable:
            null_clause = ''
        else:
            null_clause = ' NOT NULL'

        if self.default:
            default_clause = f' DEFAULT {self.default}'
        else:
            default_clause = ''

        return (f'{self.name} {self.type_.name}'
                f'{null_clause}{default_clause}')

    def __str__(self):
        return self.name

==> ajsonapi-0.9.3-py3-none-any.whl: ajsonapi/attribute.py <==
# Copyright © 2018-2020 Roel van der Goot
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
"""Module attribute provides class Attribute."""

from ajsonapi.field import Field


class Attribute(Field):
    """Attributes are used to specify data members of object model classes
    (classes derived from JSON_API).
    """

    def __init__(self, type_, *, nullable=False, default=None):
        self.type_ = type_
        self.name = ''  # Overridden in JSON_API.__init_subclass__
        self.nullable = nullable
        self.default = default

    def filter_values(self, values):
        sql_values = [self.type_.sql(value) for value in values]
        return ','.join(sql_values)

    def filter_condition(self, values):
        return values

    def sql(self):
        """Creates the SQL column definition for this attribute.

        Returns:
            A string containing the SQL column definition for this attribute.
        """

        if self.nullable:
            null_clause = ''
        else:
            null_clause = ' NOT NULL'

        if self.default:
            default_clause = f' DEFAULT {self.type_.sql(self.default)}'
        else:
            default_clause = ''

        return (f'{self.name} {self.type_.name}'
                f'{null_clause}{default_clause}')

    def __str__(self):
        return self.name
